@@ -446,6 +446,8 @@ our %exts = ( # possibly no 'x-something', as per RFC 6648
 	nid	=> 'Nikon IPTC Data',
 	nk	=> 'Nuke File',
 	nrw	=> 'Nikon Raw Image',
+	ntc	=> ['Natron Cache File', 'application/vnd.natron.cachefile'],
+	ntp	=> ['Natron Project File', 'application/vnd.natron.project'],
 	nut	=> ['NUT Open Container Format File', 'application/octet-stream'], # mime type?
 	nwb	=> 'Nikon White Balance File',
 	ogg	=> 'OGG Media',
@@ -515,6 +517,7 @@ our %exts = ( # possibly no 'x-something', as per RFC 6648
 	wav	=> ['Waveform Audio File Format File', 'audio/wav'],	# audio/vnd.wave, audio/wave
 	webm	=> ['WebM Audio-/Video File', 'video/webm'],	# also audio/webm
 	webp	=> ['WebP Image', 'image/webp'],
+	wcl	=> ['Wrangler Column Layout', 'application/json'],	# exported/imported by Settings::Filebrowser, is application/json
 	wfl	=> ['Wrangler Field Layout', 'application/json'],	# exported/imported by FormEditor, is application/json
 	wma	=> ['Windows Media Audio', 'audio/ms-wma'],
 	wmv	=> ['Windows Media Video', 'audio/ms-wmv'],
