@@ -69,6 +69,8 @@ use Wx qw(wxDefaultPosition wxDefaultSize wxDEFAULT_DIALOG_STYLE wxEXPAND wxGROW
 use Wx::Event qw(EVT_PAINT);
 use base 'Wx::Panel';
 
+use utf8; # text here is utf8 ("looking at you, (c)..!")
+
 sub new {
 	my $class = shift;
 	my $parent = shift;
@@ -79,7 +81,9 @@ sub new {
 	$self->{panel} = Wx::Panel->new($self, -1, wxDefaultPosition, [425,251], wxGROW);
 	$self->{bmp} = Wx::Bitmap->newFromXPM($Wrangler::Images::image{'logo_2.x_splash425'});
 
-	my $text = Wx::StaticText->new($self, -1, "This is Wrangler.\nVersion $Wrangler::VERSION\n\n© 2009-2014 Clipland GmbH. All rights reserved.");
+	my $wrangler_version = $Wrangler::VERSION;
+	$wrangler_version =~ s/,/\./;
+	my $text = Wx::StaticText->new($self, -1, "This is Wrangler.\nVersion ". $wrangler_version ."\n\n© 2009-2015 Clipland GmbH. All rights reserved.");
 	$text->SetForegroundColour(Wx::Colour->new(45,45,45) );
 
 	my $sizer = Wx::FlexGridSizer->new(2, 1, 0, 0);	# rows,cols,vgap,hgap
